@@ -58,4 +58,39 @@ test_that("Size bigger then cap simply yield one bin.", {
     bin_pack_ffd(x, cap = 1, sort = FALSE),
     c(0, 1, 2, 2)
   )
+
+  expect_equal(
+    bin_pack_ffd(c(11, 11, 11, 3, 7), cap = 10),
+    c(0, 1, 2, 3, 3)
+  )
+})
+
+test_that("NAs are treated correctly.", {
+  x <- c(1, 2, 3, NA, 4, 5)
+
+  expect_equal(
+    bin_pack_ffd(x, 5),
+    c(1, 2, 2, NA, 1, 0)
+  )
+})
+
+test_that("Results are the same as BBmisc reference implementation", {
+  skip_if_not_installed("BBmisc", "1.13")
+
+  hedgehog::forall(
+    list(
+      size = hedgehog::gen.int(100),
+      length = hedgehog::gen.int(1000),
+      cap_factor = hedgehog::gen.int(10)
+    ),
+    function(size, length, cap_factor) {
+      x <- rep(size, length)
+      cap <- size * cap_factor
+
+      expect_equal(
+        bin_pack_ffd(x, cap) + 1,
+        BBmisc::binPack(x, cap)
+      )
+    }
+  )
 })
